==> prestashop_1.4.4.1.zip: prestashop/modules/livezilla/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{livezilla}prestashop>livezilla_2b6ffc604d5470a856c3a7bba581d1ae'] = 'Live Support Chat';
$_MODULE['<{livezilla}prestashop>livezilla_c888438d14855d7d96a2724ee9c306bd'] = 'Einstellungen aktualisiert';
$_MODULE['<{livezilla}prestashop>livezilla_1445650302f377af43ee1f7738dc7b50'] = 'Anleitungen';
$_MODULE['<{livezilla}prestashop>livezilla_3e4804ddb635637d8b873f7cfee85ed5'] = 'LiveZilla ist keine gehostete Lösung, das heißt, das LiveZilla auf Ihrem lokalen Computer (Schritt 1) und auf Ihrem Webserver (Schritt 2) installiert werden muss bedeutet.';
$_MODULE['<{livezilla}prestashop>livezilla_f3a98489037e44119b187247b5894526'] = 'Die LiveZilla Installation auf Ihrem Webserver heißt LiveZilla Server.';
$_MODULE['<{livezilla}prestashop>livezilla_1965c2fd150423248634c52fc53c6e80'] = 'Die vollständige Installationsanleitung finden Sie auf';
$_MODULE['<{livezilla}prestashop>livezilla_10827a74160be97df6c0873f7c9809b9'] = 'der offiziellen LiveZilla Webseite ';
$_MODULE['<{livezilla}prestashop>livezilla_0f7c0aba4acddebc7d72b7a91d339d46'] = 'Jetzt LiveZilla downloaden !';
$_MODULE['<{livezilla}prestashop>livezilla_254f642527b45bc260048e30704edb39'] = 'Konfiguration';
$_MODULE['<{livezilla}prestashop>livezilla_e6e29281ee59dd8ab5c79b21737b6430'] = 'Geben Sie die URL für Ihre LiveZilla Installation ein';
$_MODULE['<{livezilla}prestashop>livezilla_a1c537e365d5243201b00d3ea5a1ea00'] = 'Endgültige URL mit dem Schrägstrich, z.B.';
$_MODULE['<{livezilla}prestashop>livezilla_c718af0f8ee7235462f7c70ef974b2e7'] = '- ODER -';
$_MODULE['<{livezilla}prestashop>livezilla_66a4362239a5cf0c365bacbf13e98ee0'] = 'Kopieren das von LiveZilla erhaltene Skript ';
$_MODULE['<{livezilla}prestashop>livezilla_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{livezilla}prestashop>livezilla_2bc19baeea1dd9e939091b1d414da0f7'] = 'LiveZilla Live Help';

==> prestashop_1.4.8.2.zip: prestashop/modules/livezilla/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{livezilla}prestashop>livezilla_2bc19baeea1dd9e939091b1d414da0f7'] = 'LiveZilla Live Help';
$_MODULE['<{livezilla}prestashop>livezilla_2b6ffc604d5470a856c3a7bba581d1ae'] = 'Live Support Chat';
$_MODULE['<{livezilla}prestashop>livezilla_c888438d14855d7d96a2724ee9c306bd'] = 'Einstellungen aktualisiert';
$_MODULE['<{livezilla}prestashop>livezilla_1445650302f377af43ee1f7738dc7b50'] = 'Anleitungen';
$_MODULE['<{livezilla}prestashop>livezilla_3e4804ddb635637d8b873f7cfee85ed5'] = 'LiveZilla ist keine gehostete Lösung, das heißt, das LiveZilla auf Ihrem lokalen Computer (Schritt 1) und auf Ihrem Webserver (Schritt 2) installiert werden muss bedeutet.';
$_MODULE['<{livezilla}prestashop>livezilla_f3a98489037e44119b187247b5894526'] = 'Die LiveZilla Installation auf Ihrem Webserver heißt LiveZilla Server.';
$_MODULE['<{livezilla}prestashop>livezilla_6dc42b5059b4c589e225323855cd1100'] = 'Nachdem Schritt 1 & 2 abgeschlossen ist, müssen Sie die Domain Ihrer Live-Zilla Installation eintragen (mittels kopieren & einfügen z.B.). Nachdem die Domain eingetragen ist, wird dies mit Schritt 3 abgeschlossen.';
$_MODULE['<{livezilla}prestashop>livezilla_1965c2fd150423248634c52fc53c6e80'] = 'Die vollständige Installationsanleitung finden Sie auf';
$_MODULE['<{livezilla}prestashop>livezilla_10827a74160be97df6c0873f7c9809b9'] = 'der offiziellen LiveZilla Webseite ';
$_MODULE['<{livezilla}prestashop>livezilla_0f7c0aba4acddebc7d72b7a91d339d46'] = 'Jetzt LiveZilla downloaden !';
$_MODULE['<{livezilla}prestashop>livezilla_254f642527b45bc260048e30704edb39'] = 'Konfiguration';
$_MODULE['<{livezilla}prestashop>livezilla_e6e29281ee59dd8ab5c79b21737b6430'] = 'Geben Sie die URL für Ihre LiveZilla Installation ein';
$_MODULE['<{livezilla}prestashop>livezilla_a1c537e365d5243201b00d3ea5a1ea00'] = 'Endgültige URL mit dem Schrägstrich, z.B.';
$_MODULE['<{livezilla}prestashop>livezilla_c718af0f8ee7235462f7c70ef974b2e7'] = '- ODER -';
$_MODULE['<{livezilla}prestashop>livezilla_66a4362239a5cf0c365bacbf13e98ee0'] = 'Kopieren das von LiveZilla erhaltene Skript ';
$_MODULE['<{livezilla}prestashop>livezilla_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';

?>
